# Developer guide

Welcome to the **SplitterMR Python API** reference.

![SplitterMR architecture diagram](https://raw.githubusercontent.com/andreshere00/Splitter_MR/refs/heads/main/assets/architecture_splitter_mr.svg)

## Documentation

### [Reader component documentation](./reader.md)

Use several reading methods to process your files.

### [Model component documentation](./model.md)

Add VLMs (Visual Language Models) to analyse your images from your documents.

### [Splitter component documentation](./splitter.md)

Implement several splitting strategies based on your needs.
